@@ -5,5 +5,6 @@ Instance-Based Methods Module
 from ._kliep import KLIEP
 from ._kmm import KMM
 from ._tradaboost import TrAdaBoost, TrAdaBoostR2, TwoStageTrAdaBoostR2
+from ._wann import WANN
 
-__all__ = ["KLIEP", "KMM", "TrAdaBoost", "TrAdaBoostR2", "TwoStageTrAdaBoostR2"]
\ No newline at end of file
+__all__ = ["KLIEP", "KMM", "TrAdaBoost", "TrAdaBoostR2", "TwoStageTrAdaBoostR2", "WANN"]
\ No newline at end of file
