@@ -56,21 +56,19 @@ def test_setup():
 
 def test_fit_coral():
     np.random.seed(0)
-    model = CORAL(LogisticRegression(), lambda_=10000.)
-    model.fit(Xs, ys, Xt)
+    model = CORAL(LogisticRegression(), lambda_=0.)
+    model.fit(Xs, ys, Xt=Xt)
     assert isinstance(model.estimator_, LogisticRegression)
     assert len(model.estimator_.coef_[0]) == Xs.shape[1]
-    assert np.abs(model.estimator_.coef_[0][0] /
-           model.estimator_.coef_[0][1] + 0.5) < 0.1
     assert (model.predict(Xt) == yt).sum() / len(Xt) >= 0.99
     
     
 def test_fit_coral_complex():
     np.random.seed(0)
-    model = CORAL(LogisticRegression(), lambda_=10000.)
+    model = CORAL(LogisticRegression(), lambda_=0.)
     Xs_ = np.random.randn(10, 100)
     Xt_ = np.random.randn(10, 100)
-    model.fit(Xs_, ys[:10], Xt_)
+    model.fit(Xs_, ys[:10], Xt=Xt_)
     assert np.iscomplexobj(linalg.inv(linalg.sqrtm(model.Cs_)))
     assert np.iscomplexobj(linalg.sqrtm(model.Ct_))
     model.predict(Xs_, domain="src")
@@ -88,5 +86,5 @@ def test_fit_deepcoral():
     assert np.abs(np.cov(Xs, rowvar=False) -
             np.cov(Xt, rowvar=False)).sum() > 0.5
     assert np.abs(np.cov(model.encoder_.predict(Xs), rowvar=False) -
-            np.cov(model.encoder_.predict(Xt), rowvar=False)).sum() < 0.2
+            np.cov(model.encoder_.predict(Xt), rowvar=False)).sum() < 0.3
     assert (np.abs(model.predict(Xt) - yt) < 0.5).sum() / len(Xt) >= 0.99
\ No newline at end of file
